@@ -133,8 +133,7 @@ class GoogleAnalyticsAPI_V4:
             *[z for y in x['metrics']
               for z in y['values']]
         ]
-        rows = first_response['data'].get('rows', [])
-        yield from map(yield_handler, rows)
+        yield from map(yield_handler, first_response['data'].get('rows', []))
 
         batch_limit -= 1
         if total_results > max_results:
@@ -144,7 +143,7 @@ class GoogleAnalyticsAPI_V4:
                     self.client.reports().batchGet(body=params).execute
                 )['reports'][0]
 
-                yield from map(yield_handler, rows)
+                yield from map(yield_handler, response['data'].get('rows', []))
                 batch_limit -= 1
 
                 if 'nextPageToken' not in response:
@@ -162,7 +161,7 @@ class GoogleAnalyticsAPI_V3:
     """ Google Analytics API is a proxy sub-library for an origin Python API library of Google.
         So it is rather different from other APIs.
 
-        :arg credentials:
+        :arg credentials: a dictionary with data is needed for GA connection
 
         For now, here supports only Core API v3
         Documentation: https://developers.google.com/analytics/devguides/reporting/core/v3?hl=ru
@@ -272,15 +271,13 @@ class GoogleAnalyticsAPI_V3:
         if not is_accessed_sampling and first_response['containsSampledData']:
             raise Exception(f'Contains sampled data. Request: {params}')
 
-        rows = first_response.get('rows', [])
-        yield from rows
+        yield from first_response.get('rows', [])
 
         if batch_limit == 1:
             logging.info(f'Received {total_results} records')
 
         elif total_results > first_response['itemsPerPage']:
             params['start_index'] = max_results - 1
-            yield from rows
             while True:
                 response = self.client.data().ga().get(**params).execute(num_retries=3)
 
